pub struct ChainAuthProvider { /* private fields */ }Expand description
Provider that consults an ordered list of providers; the first Some wins,
for both transport and signing resolution.
Implementations
Sourceimpl ChainAuthProvider
impl ChainAuthProvider
Sourcepub fn new(providers: Vec<Arc<dyn AuthProvider>>) -> Self
pub fn new(providers: Vec<Arc<dyn AuthProvider>>) -> Self
Create a chain from an ordered list of providers.
Sourcepub fn with(self, provider: Arc<dyn AuthProvider>) -> Self
pub fn with(self, provider: Arc<dyn AuthProvider>) -> Self
Append a provider to the end of the chain.