Embedded libgit2 repository implementation.
Modules
- auth
git2authentication helpers.
Structs
- Git2
Repository - Repository implementation backed by libgit2.
Functions
- clone
- Clones a git repository into the given path.
- discover
- Discovers a git repository by walking up from the given path.
- discover_
with_ auth - Discovers a git repository by walking up from
pathwith an explicit auth provider. - init
- Creates a new git repository at the given path.
- init_
bare - Creates a new bare git repository at the given path.
- init_
with - Creates a new git repository at the given path with explicit options.
- open
- Opens a git repository at the given path (canonicalized).
- open_
with_ auth - Opens a git repository at the given path with an explicit auth provider.