pub fn validate_transport(auth: &TransportAuth) -> AppResult<()>Expand description
Validates that the requested transport auth can be expressed for git2.
pub fn validate_transport(auth: &TransportAuth) -> AppResult<()>Validates that the requested transport auth can be expressed for git2.