pub fn discover(path: impl AsRef<Path>) -> AppResult<Git2Repository>Expand description
Discovers a git repository by walking up from the given path.
pub fn discover(path: impl AsRef<Path>) -> AppResult<Git2Repository>Discovers a git repository by walking up from the given path.