pub fn discover_with_auth(
path: impl AsRef<Path>,
auth: Arc<dyn AuthProvider>,
) -> AppResult<Git2Repository>Expand description
Discovers a git repository by walking up from path with an explicit auth provider.
pub fn discover_with_auth(
path: impl AsRef<Path>,
auth: Arc<dyn AuthProvider>,
) -> AppResult<Git2Repository>Discovers a git repository by walking up from path with an explicit auth provider.