pub fn init_with(
path: impl AsRef<Path>,
options: &InitOptions,
) -> AppResult<Git2Repository>Expand description
Creates a new git repository at the given path with explicit options.
pub fn init_with(
path: impl AsRef<Path>,
options: &InitOptions,
) -> AppResult<Git2Repository>Creates a new git repository at the given path with explicit options.