pub fn open(path: impl AsRef<Path>) -> AppResult<Git2Repository>Expand description
Opens a git repository at the given path (canonicalized).
pub fn open(path: impl AsRef<Path>) -> AppResult<Git2Repository>Opens a git repository at the given path (canonicalized).