pub fn open_with_auth(
path: impl AsRef<Path>,
auth: Arc<dyn AuthProvider>,
) -> AppResult<Git2Repository>Expand description
Opens a git repository at the given path with an explicit auth provider.
pub fn open_with_auth(
path: impl AsRef<Path>,
auth: Arc<dyn AuthProvider>,
) -> AppResult<Git2Repository>Opens a git repository at the given path with an explicit auth provider.