Module embedded

Module embedded 

Embedded libgit2 repository implementation.

Modules

auth
git2 authentication helpers.

Structs

Git2Repository
Repository implementation backed by libgit2.

Functions

clone
Clones a git repository into the given path.
discover
Discovers a git repository by walking up from the given path.
init
Creates a new git repository at the given path.
init_bare
Creates a new bare git repository at the given path.
open
Opens a git repository at the given path (canonicalized).