Module embedded
rskit_
git
0.2.0-alpha.1
Module embedded
Module Items
Modules
Structs
Functions
In crate rskit_
git
rskit_git
Module
embedded
Embedded libgit2 repository implementation.
Modules

auth
git2
authentication helpers.
Structs

Git2
Repository
Repository implementation backed by libgit2.
Functions

clone
Clones a git repository into the given path.
discover
Discovers a git repository by walking up from the given path.
init
Creates a new git repository at the given path.
init_
bare
Creates a new bare git repository at the given path.
open
Opens a git repository at the given path (canonicalized).