pub fn init_bare(path: impl AsRef<Path>) -> AppResult<Git2Repository>Expand description
Creates a new bare git repository at the given path.
The initial branch is DEFAULT_BRANCH, matching init.
pub fn init_bare(path: impl AsRef<Path>) -> AppResult<Git2Repository>Creates a new bare git repository at the given path.
The initial branch is DEFAULT_BRANCH, matching init.