Module repo
rskit_
git
0.2.0-alpha.1
Module repo
Module Items
Structs
Functions
In crate rskit_
git
rskit_git
Module
repo
Repository orchestrator that delegates to libgit2 and Git CLI implementations.
Structs

Repo
Repository facade that combines embedded and CLI capabilities.
Functions

clone
Clones a repository into the given path.
discover
Discovers a git repository by walking up from the given path.
init
Initializes a new git repository at the given path.
init_
bare
Initializes a new bare git repository at the given path.
open
Opens a git repository at the given path (canonicalized).